@@ -15,7 +15,7 @@
 import os
 import sys
 
-from django.core.management import execute_from_command_line  # noqa
+from django.core.management import execute_from_command_line
 
 if __name__ == "__main__":
     os.environ.setdefault("DJANGO_SETTINGS_MODULE",
