@@ -12,7 +12,7 @@
 
 import yaml
 
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 from senlin_dashboard.api import senlin
@@ -39,6 +39,8 @@ class IndexView(tables.DataTableView):
         return getattr(self, "_more", False)
 
     def get_data(self):
+        filters = self.get_filters()
+
         prev_marker = self.request.GET.get(
             PoliciesTable._meta.prev_pagination_param, None)
 
@@ -53,7 +55,8 @@ class IndexView(tables.DataTableView):
                 self.request,
                 marker=marker,
                 paginate=True,
-                reversed_order=reversed_order)
+                reversed_order=reversed_order,
+                filters=filters)
         except Exception:
             self._prev = self._more = False
             policies = []
@@ -64,11 +67,15 @@ class IndexView(tables.DataTableView):
 
 class CreateView(forms.ModalFormView):
     template_name = 'cluster/policies/create.html'
-    page_title = _("Create Policy")
     form_class = policies_forms.CreatePolicyForm
     submit_url = reverse_lazy(policies_forms.CREATE_URL)
     success_url = reverse_lazy(policies_forms.INDEX_URL)
 
+    text = _("Create Policy")
+    modal_header = text
+    submit_label = text
+    page_title = text
+
 
 class DetailView(tabs.TabView):
     tab_group_class = policies_tabs.PolicyDetailTabs
@@ -101,3 +108,40 @@ class DetailView(tabs.TabView):
     def get_tabs(self, request, *args, **kwargs):
         policy = self.get_object()
         return self.tab_group_class(request, policy=policy, **kwargs)
+
+
+class UpdateView(forms.ModalFormView):
+    template_name = 'cluster/policies/update.html'
+    form_class = policies_forms.UpdatePolicyForm
+    submit_url = reverse_lazy(policies_forms.UPDATE_URL)
+    success_url = reverse_lazy(policies_forms.INDEX_URL)
+
+    text = _("Update Policy")
+    modal_header = text
+    submit_label = text
+    page_title = text
+
+    @memoized.memoized_method
+    def get_object(self):
+        try:
+            # Get initial policy information
+            policy_id = self.kwargs["policy_id"]
+            policy = senlin.policy_get(self.request, policy_id)
+            policy_dict = {"policy_id": policy_id,
+                           "name": policy.name}
+        except Exception:
+            msg = _("Unable to retrieve policy.")
+            url = reverse_lazy(policies_forms.INDEX_URL)
+            exceptions.handle(self.request, msg, redirect=url)
+        return policy_dict
+
+    def get_context_data(self, **kwargs):
+        args = (self.kwargs["policy_id"],)
+        context = super(UpdateView, self).get_context_data(**kwargs)
+        context["policy"] = self.get_object()
+        context["submit_url"] = reverse_lazy(policies_forms.UPDATE_URL,
+                                             args=args)
+        return context
+
+    def get_initial(self):
+        return self.get_object()
