@@ -11,7 +11,7 @@
 # limitations under the License.
 
 from django.conf import settings
-from django.conf.urls import url
+from django.urls import re_path
 from django.utils.translation import ugettext_lazy as _
 
 from horizon.browsers.views import AngularIndexView
@@ -23,12 +23,13 @@ from senlin_dashboard.cluster.receivers import views as legacyViews
 if settings.ANGULAR_FEATURES.get('receivers_panel', True):
     title = _("Receivers")
     urlpatterns = [
-        url(r'^$', AngularIndexView.as_view(title=title), name='index'),
+        re_path(r'^$', AngularIndexView.as_view(title=title), name='index'),
     ]
 else:
     urlpatterns = [
-        url(r'^$', legacyViews.IndexView.as_view(), name='index'),
-        url(r'^create/$', legacyViews.CreateView.as_view(), name='create'),
-        url(r'^(?P<receiver_id>[^/]+)/$',
-            legacyViews.DetailView.as_view(), name='detail'),
+        re_path(r'^$', legacyViews.IndexView.as_view(), name='index'),
+        re_path(r'^create/$', legacyViews.CreateView.as_view(),
+                name='create'),
+        re_path(r'^(?P<receiver_id>[^/]+)/$',
+                legacyViews.DetailView.as_view(), name='detail'),
     ]
